/*
 * (C) Copyright 2014 Kurento (http://kurento.org/)
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 */

#ifndef _KURENTO_MARSHAL_
#define _KURENTO_MARSHAL_

#include <gst/gst.h>
#include "kmsmessage.h"

#define KURENTO_MARSHAL_ERROR \
  g_quark_from_static_string("kurento-marshal-error-quark")

typedef enum
{
  KURENTO_UNKNOWN_TYPE,
  KURENTO_ENCODED_ERROR,
  KURENTO_DECODED_ERROR
} KurentoMarshalError;

typedef enum
{
  KURENTO_MARSHALL_BER,
  KURENTO_MARSHALL_XER,
  KURENTO_MARSHALL_PER,
} KurentoMarshalRules;

gssize enc_GstCaps (KurentoMarshalRules rules, const GstCaps * caps,
    gchar *buf, gsize size, GError ** err);
gboolean dec_GstCaps (KurentoMarshalRules rules, const gchar * buf, gsize size,
    GstCaps ** caps, GError ** err);

gssize enc_GstEvent (KurentoMarshalRules rules, const GstEvent * event,
    gchar *buf, gsize size, GError ** err);
gboolean dec_GstEvent (KurentoMarshalRules rules, const gchar * buf, gsize size,
    GstEvent ** event, GError ** err);

gssize enc_GstQuery (KurentoMarshalRules rules, const GstQuery * query,
    gchar *buf, gsize size, GError ** err);
gboolean dec_GstQuery (KurentoMarshalRules rules, const gchar * buf, gsize size,
    GstQuery ** query, GError ** err);

gssize enc_GstBuffer (KurentoMarshalRules rules, const GstBuffer * buffer,
    gchar *buf, gsize size, GError ** err);
gboolean dec_GstBuffer (KurentoMarshalRules rules, const gchar * buf, gsize size,
    GstBuffer ** buffer, GError ** err);

gssize enc_KmsMessage (KurentoMarshalRules rules,
    const KmsMessage * msg, gchar *buf, gsize size, GError ** err);
gboolean dec_KmsMessage (KurentoMarshalRules rules, const gchar * buf,
    gsize size, KmsMessage ** msg, GError ** err);

#endif /* _KURENTO_ASN1_MARSHAL_ */
